@@ -2,32 +2,40 @@
 
 
 package HiD;
-$HiD::VERSION = '1.95_92';
+$HiD::VERSION = '1.1';
+BEGIN {
+  $HiD::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 use namespace::autoclean;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
+use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Class::Load        qw/ try_load_class /;
+use Class::Load        qw/ :all /;
 use DateTime;
+use File::Basename;
 use File::Find::Rule;
-use Path::Tiny;
-use Try::Tiny;
-use YAML::Tiny;
-
+use File::Path         qw/ make_path /;
+use File::Remove       qw/ remove /;
 use HiD::File;
 use HiD::Layout;
 use HiD::Page;
 use HiD::Pager;
 use HiD::Post;
 use HiD::Types;
+use Module::Find;
+use Path::Class        qw/ file /;
+use Try::Tiny;
+use YAML::XS           qw/ LoadFile /;
 
 
 has categories => (
@@ -75,14 +83,14 @@ sub _build_config {
 
   if ( my $file = $self->config_file ) {
     try {
-      $config = YAML::Tiny->read( $file )->[0] // {};
+      $config = LoadFile( $file ) // {};
       ref $config eq 'HASH' or die $!;
       $config_loaded++;
     };
   }
 
   $config_loaded or $config = {}
-    and warn( "Could not read configuration. Using defaults (and options).\n" );
+    and warn( 'Could not read configuration. Using defaults (and options).' );
 
   return {
     %{ $self->default_config } ,
@@ -107,14 +115,13 @@ has default_config => (
   traits   => [ 'Hash' ] ,
   init_arg => undef ,
   default  => sub{{
-    default_author => 'your name here!' ,
-    destination    => '_site'    ,
-    include_dir    => '_includes',
-    layout_dir     => '_layouts' ,
-    plugin_dir     => '_plugins' ,
-    posts_dir      => '_posts' ,
-    drafts_dir     => '_drafts' ,
-    source         => '.' ,
+    destination => '_site'    ,
+    include_dir => '_includes',
+    layout_dir  => '_layouts' ,
+    plugin_dir  => '_plugins' ,
+    posts_dir   => '_posts' ,
+    drafts_dir  => '_drafts' ,
+    source      => '.' ,
   }},
 );
 
@@ -125,7 +132,7 @@ has destination => (
   lazy    => 1 ,
   default => sub {
     my $dest = shift->get_config( 'destination' );
-    path( $dest )->mkpath() unless -e -d $dest;
+    make_path $dest unless -e -d $dest;
     return $dest;
   },
 );
@@ -488,16 +495,14 @@ has processor_args => (
   default => sub {
     my $self = shift;
 
-    my $processor_args = defined $self->get_config('processor_args') ? $self->get_config('processor_args') : {};
+    return $self->get_config( 'processor_args' ) if
+      defined $self->get_config( 'processor_args' );
 
-    if(ref $processor_args eq 'HASH' && !exists $processor_args->{path}) {
-        my @path = ( $self->layout_dir );
-        push @path , $self->include_dir
-          if defined $self->include_dir;
-        $processor_args->{path} = \@path;
-    }
+    my @path = ( $self->layout_dir );
+    push @path , $self->include_dir
+      if defined $self->include_dir;
 
-    return $processor_args;
+    return { path => \@path };
   },
 );
 
@@ -610,13 +615,6 @@ has written_files => (
 sub publish {
   my( $self ) = @_;
 
-  if ( -e $self->destination && $self->get_config( 'clean_destination' )){
-    my $path = path( $self->destination );
-    $path->remove_tree();
-    $self->INFO( "cleaned destination directory" );
-    $path->mkpath();
-  }
-
   $self->INFO( "publish" );
 
   # bootstrap data structures
@@ -673,19 +671,16 @@ sub publish {
 
     $self->INFO( sprintf "* Published %s" , $file->output_filename );
 
-    my $path = path( $file->output_filename );
-    while ( $path ne '.' ) {
-      $self->add_written_file( $path->stringify() => 1 );
-      $path = $path->parent;
+    my $path;
+    foreach my $part ( split '/' , $file->output_filename ) {
+      $path = file( $path , $part )->stringify;
+      $self->add_written_file( $path => 1 );
     }
   }
 
   if ( $self->remove_unwritten_files ) {
     foreach ( File::Find::Rule->in( $self->destination )) {
-      next if $self->wrote_file($_);
-
-      my $path = path( $_ );
-      $path->is_dir ? $path->remove_tree : $path->remove;
+      $self->wrote_file($_) or remove \1 , $_;
     }
   }
 
@@ -713,7 +708,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -986,7 +981,7 @@ L<StaticVolt>
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -994,7 +989,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
