@@ -2,19 +2,23 @@
 
 
 package HiD::App;
-$HiD::App::VERSION = '1.95_92';
+$HiD::App::VERSION = '1.1';
+BEGIN {
+  $HiD::App::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 extends 'MooseX::App::Cmd';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-sub default_command { 'help' };
+sub default_command { 'publish' };
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -23,7 +27,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -35,7 +39,7 @@ See C<perldoc hid> for usage information.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -43,7 +47,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
