@@ -2,17 +2,21 @@
 
 
 package HiD::App::Command;
-$HiD::App::Command::VERSION = '1.95_92';
+$HiD::App::Command::VERSION = '1.1';
+BEGIN {
+  $HiD::App::Command::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 extends 'MooseX::App::Cmd::Command';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use HiD;
 
@@ -26,15 +30,12 @@ has config_file => (
 );
 
 has hid => (
-  is        => 'ro' ,
-  isa       => 'HiD' ,
-  lazy      => 1 ,
-  traits    => [ qw/ NoGetopt/ ] ,
-  init_arg  => undef ,
-  clearer   => '_clear_hid' ,
-  predicate => '_has_hid' ,
-  builder   => '_build_hid' ,
-  handles   => [
+  is       => 'ro' ,
+  isa      => 'HiD' ,
+  traits   => [ qw/ NoGetopt/ ] ,
+  init_arg => undef ,
+  writer   => '_set_hid' ,
+  handles  => [
     'all_objects' ,
     'config' ,
     'destination' ,
@@ -42,15 +43,7 @@ has hid => (
   ] ,
 );
 
-sub _build_hid { HiD->new( shift->hid_config ) }
-
-has hid_config => (
-  is       => 'ro' ,
-  isa      => 'HashRef' ,
-  traits   => [ qw/ NoGetopt / ] ,
-  init_arg => undef ,
-  writer   => '_set_hid_config' ,
-);
+sub _build_hid { return HiD->new }
 
 sub execute {
   my( $self , $opts , $args ) = @_;
@@ -68,20 +61,11 @@ sub execute {
     $hid_config->{config_file} = $self->config_file
   }
 
-  $self->_set_hid_config( $hid_config );
+  $self->_set_hid( HiD->new($hid_config) );
 
   $self->_run( $opts , $args );
 }
 
-
-sub reset_hid {
-  my( $self ) = @_;
-
-  $self->_clear_hid() if $self->_has_hid();
-
-  return $self->hid();
-}
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -89,7 +73,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -123,16 +107,9 @@ Path to config file.
 
 Defaults to './_config.yml'
 
-=head1 METHODS
-
-=head2 reset_hid
-
-Clear out the existing L<HiD> object attribute, generate a fresh one with the
-stored configuration information, and return it.
-
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -140,7 +117,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
