@@ -2,19 +2,23 @@
 
 
 package HiD::App::Command::init;
-$HiD::App::Command::init::VERSION = '1.95_92';
+$HiD::App::Command::init::VERSION = '1.1';
+BEGIN {
+  $HiD::App::Command::init::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use YAML::Tiny;
+use YAML::XS qw/ DumpFile /;
 
 
 has blog => (
@@ -61,8 +65,9 @@ EOF
 
   $self->_init_blog if $self->blog;
 
-  my $yaml = YAML::Tiny->new({ title => $self->title });
-  $yaml->write( '_config.yml' );
+  DumpFile( '_config.yml' , {
+    title => $self->title ,
+  });
 
   say "Enjoy your new site!";
 }
@@ -100,7 +105,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -147,7 +152,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -155,7 +160,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
