@@ -2,13 +2,16 @@
 
 
 package HiD::App::Command::server;
-$HiD::App::Command::server::VERSION = '1.95_92';
+$HiD::App::Command::server::VERSION = '1.1';
+BEGIN {
+  $HiD::App::Command::server::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 extends 'HiD::App::Command';
 with 'HiD::Role::PublishesDrafts';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
@@ -16,13 +19,9 @@ use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 use feature     qw/ unicode_strings /;
 
-use Class::Load      qw/ try_load_class /;
-use Plack::Builder;
-use Plack::Runner;
+use namespace::autoclean;
 
-use HiD::Server;
-use HiD::Server::Handler;
-use HiD::Server::Loader;
+use Plack::Runner;
 
 
 has auto_refresh => (
@@ -36,22 +35,6 @@ has auto_refresh => (
 );
 
 
-has clean => (
-  is          => 'ro' ,
-  isa         => 'Bool' ,
-  cmd_aliases => 'C' ,
-  traits      => [ 'Getopt' ] ,
-);
-
-
-has debug => (
-  is          => 'ro' ,
-  isa         => 'Bool' ,
-  cmd_aliases => 'D' ,
-  traits      => [ 'Getopt' ] ,
-);
-
-
 has port => (
   is            => 'ro' ,
   isa           => 'Int' ,
@@ -74,33 +57,16 @@ sub _build_port {
 sub _run {
   my( $self , $opts , $args ) = @_;
 
-  my $config = $self->config;
-  if ( $self->clean ) {
-    $config->{clean_destination} = 1;
-  }
-
+  my $config = {};
   if ( $self->publish_drafts ){
     $config->{publish_drafts} = 1;
   }
 
+  $self->publish;
+
   my $app = HiD::Server->new( root => $self->destination )->to_app;
 
-  if ( $self->debug ) {
-    if ( try_load_class( 'Plack::Middleware::DebugLogging' )) {
-      $app = builder {
-        enable_if { $ENV{PLACK_ENV} eq 'development' } 'DebugLogging';
-        $app;
-      };
-    }
-    else {
-      print STDERR "*** Plack::Middleware::DebugLogging required for debug logging.\n";
-      print STDERR "*** Continuing with normal logging.\n";
-    }
-  }
-
-  my $runner = Plack::Runner->new;
-  my %args   = ( '-p' => $self->port );
-  $runner->parse_options(%args);
+  my %args = ( -p => $self->port );
 
   # auto refresh
   if ( $self->auto_refresh ) {
@@ -110,29 +76,54 @@ sub _run {
       push @dirs, map { $_->input_filename } @{ $self->hid->$dir };
     }
 
-    # FIXME wish there was a better way to override stuff in Plack::Runner. >_<
-    $runner->{server} = '+HiD::Server::Handler';
-    $runner->{loader} = '+HiD::Server::Loader';
-    $runner->loader->watch(@dirs);
+    $args{'-R'} = join ',', @dirs;
+    $args{'-r'} = 1;
 
-    push @{$runner->{options}} , ( hid => $self );
-
-    # no need to explicitly ->publish() here, as that will happen inside
-    # HiD::Server::Loader, in the child, after the fork.
+    my $original_app = $app;
+    $app = \sub {
+      say 'Rebuild ... ';
+      $self->publish;
+      $original_app;
+    };
   }
-  else { $self->publish() }
 
+  my $runner = Plack::Runner->new;
+  $runner->parse_options(%args);
   $runner->run($app);
 }
 
 __PACKAGE__->meta->make_immutable;
+
+package # hide...
+  HiD::Server;
+
+use parent 'Plack::App::File';
+
+sub locate_file  {
+  my ($self, $env) = @_;
+
+  my $path = $env->{PATH_INFO} || '';
+
+  $path =~ s|^/|| unless $path eq '/';
+
+  if ( -e -d $path and $path !~ m|/$| ) {
+    $path .= '/';
+    $env->{PATH_INFO} .= '/';
+  }
+
+  $env->{PATH_INFO} .= 'index.html'
+    if ( $path && $path =~ m|/$| );
+
+  return $self->SUPER::locate_file( $env );
+}
+
 1;
 
 __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -153,17 +144,6 @@ Start a Plack-based web server that serves your C<destination> directory.
 
 Automatically refresh result when source file/dir changed, just likey jekyll
 
-Note that setting this will also clean out the destination directory whenever
-a watched file changes.
-
-=head2 clean
-
-Remove any existing site directory prior to the publication run
-
-=head2 debug
-
-Emit debug-style logging for requests
-
 =head2 port
 
 Port number to bind. Defaults to 5000.
@@ -175,7 +155,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -183,7 +163,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
