@@ -2,33 +2,22 @@
 
 
 package HiD::Generator;
-$HiD::Generator::VERSION = '1.95_92';
+$HiD::Generator::VERSION = '1.1';
+BEGIN {
+  $HiD::Generator::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose::Role;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
-
-use Path::Tiny;
+use feature    qw/ unicode_strings /;
 
 requires 'generate';
 
 
-sub _create_destination_directory_if_needed {
-  my( $self , $dest ) = @_;
-
-  $dest = path( $dest );
-
-  $self->FATAL( "'$dest' exists and is not a directory!" )
-    if $dest->is_file;
-
-  $dest->mkpath;
-
-  return 1;
-}
-
 no Moose::Role;
 1;
 
@@ -36,7 +25,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -63,7 +52,7 @@ $site->posts >> and so on.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -71,7 +60,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
