@@ -2,20 +2,26 @@
 
 
 package HiD::Page;
-$HiD::Page::VERSION = '1.95_92';
+$HiD::Page::VERSION = '1.1';
+BEGIN {
+  $HiD::Page::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 with 'HiD::Role::IsConverted';
 with 'HiD::Role::IsPublished';
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Path::Tiny;
+use File::Basename  qw/ fileparse /;
+use File::Path      qw/ make_path /;
+use Path::Class     qw/ file / ;
 
 
 sub get_default_layout { 'default' }
@@ -24,12 +30,13 @@ sub get_default_layout { 'default' }
 sub publish {
   my $self = shift;
 
-  my $out = path( $self->output_filename );
-  my $dir = $out->parent;
+  my( undef , $dir ) = fileparse( $self->output_filename );
 
-  $dir->mkpath unless $dir->is_dir;
+  make_path $dir unless -d $dir;
 
-  $out->spew_utf8( $self->rendered_content );
+  open( my $out , '>:utf8' , $self->output_filename ) or die $!;
+  print $out $self->rendered_content;
+  close( $out );
 }
 
 # used to populate the 'url' attr in Role::IsPublished
@@ -39,12 +46,10 @@ sub _build_url {
   my $format = $self->get_metadata( 'permalink' ) // 'none';
 
   my $source = $self->source;
-
   my $path_frag = $self->input_path;
   $path_frag =~ s/^$source//;
-  $path_frag ||= Path::Tiny->rootdir();
 
-  my $naive = path( $path_frag , $self->basename() );
+  my $naive = join '/' , $path_frag , $self->basename;
 
   my %_valid_exts = map { $_=>1 } qw(rss xml html htm xhtml xhtm shtml shtm);
   my $ext = exists $_valid_exts{$self->ext} ? $self->ext : 'html';
@@ -67,7 +72,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -107,7 +112,7 @@ object from this class works.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -115,7 +120,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
