@@ -2,19 +2,24 @@
 
 
 package HiD::Pager;
-$HiD::Pager::VERSION = '1.95_92';
+$HiD::Pager::VERSION = '1.1';
+BEGIN {
+  $HiD::Pager::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
 
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
+use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Data::Page;
 use String::Errf    qw/ errf /;
@@ -150,7 +155,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -254,7 +259,7 @@ Returns the URL for the previous page in the set.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -262,7 +267,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
