@@ -2,15 +2,20 @@
 
 
 package HiD::Plugin;
-$HiD::Plugin::VERSION = '1.95_92';
+$HiD::Plugin::VERSION = '1.1';
+BEGIN {
+  $HiD::Plugin::AUTHORITY = 'cpan:GENEHACK';
+}
+
 use Moose;
 use namespace::autoclean;
 
-use 5.014;  # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings   qw/ FATAL utf8 /;
 use charnames  qw/ :full           /;
+use feature    qw/ unicode_strings /;
 
 
 sub after_publish { 1 }
@@ -21,7 +26,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -42,7 +47,7 @@ Base class for plugin object
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -50,7 +55,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
