@@ -2,17 +2,21 @@
 
 
 package HiD::Processor::IIBlog;
-$HiD::Processor::IIBlog::VERSION = '1.95_92';
+$HiD::Processor::IIBlog::VERSION = '1.1';
+BEGIN {
+  $HiD::Processor::IIBlog::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 extends 'HiD::Processor';
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Text::Xslate;
 
@@ -60,7 +64,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -77,7 +81,7 @@ publication.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -85,7 +89,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
