@@ -2,17 +2,21 @@
 
 
 package HiD::Processor::Template;
-$HiD::Processor::Template::VERSION = '1.95_92';
+$HiD::Processor::Template::VERSION = '1.1';
+BEGIN {
+  $HiD::Processor::Template::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 extends 'HiD::Processor';
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Template;
 
@@ -31,39 +35,9 @@ sub BUILDARGS {
 
   my %args = ( ref $_[0] && ref $_[0] eq 'HASH' ) ? %{ $_[0] } : @_;
 
-  # Try to resolve the include path for Template
-  my @path = ();
-
-  # It might be set in the configuration file
-  if(exists $args{INCLUDE_PATH}) {
-      # Try to evaluate as an array
-      my $rc = eval { @path = @{ $args{INCLUDE_PATH} }; 1; };
-      # If that fails, treat as a string and split ':'
-      @path = split /:/, $args{INCLUDE_PATH}
-        if !$rc;
-  }
-
-  # If we got a default 'path' element, append it to the list.
-  if(exists $args{path}) {
-      # It should be an array
-      my $default_path = delete $args{path};
-      my $rc = eval { push @path, @{ $default_path }; 1; };
-      # If it's not, split on the ':' in the string
-      push @path, split /:/, $default_path
-          if !$rc;
-  }
-
-  # Finally set the path to the merged path
-  $args{INCLUDE_PATH} = \@path;
-
   return { tt => Template->new( %args ) };
 }
 
-
-sub error {
-    die $Template::ERROR;
-}
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -71,7 +45,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -85,15 +59,9 @@ HiD::Processor::Template - Use Template Toolkit to publish your HiD files
 
 Wraps up a L<Template> object and allows it to be used during HiD publication.
 
-=head1 METHODS
-
-=head2 error
-
-Display the template error message.
-
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -101,7 +69,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
