@@ -1,11 +1,12 @@
 #ABSTRACT: Logging role
 
 package HiD::Role::DoesLogging;
-$HiD::Role::DoesLogging::VERSION = '1.95_92';
+$HiD::Role::DoesLogging::VERSION = '1.1';
+BEGIN {
+  $HiD::Role::DoesLogging::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose::Role;
 
-use 5.014;  # strict, unicode_strings
-
 use Log::Log4perl;
 
 requires 'get_config';
@@ -61,7 +62,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -98,7 +99,7 @@ Log4perl object for logging. Handles:
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -106,7 +107,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
