@@ -2,23 +2,27 @@
 
 
 package HiD::Role::IsConverted;
-$HiD::Role::IsConverted::VERSION = '1.95_92';
+$HiD::Role::IsConverted::VERSION = '1.1';
+BEGIN {
+  $HiD::Role::IsConverted::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Carp;
-use Class::Load  qw/ load_class /;
-use Path::Tiny;
-use YAML::XS     qw/ Load /; # YAML::Tiny doesn't support 'bool' types which we need 8^/
-
+use Class::Load  qw/ :all /;
+use Encode;
+use File::Slurp  qw/ read_file /;
 use HiD::Types;
+use YAML::XS     qw/ Load /;
 
 requires 'get_default_layout';
 
@@ -137,14 +141,15 @@ has template_data => (
     my $self = shift;
 
     my $data = {
-      baseurl  => $self->hid->config->{baseurl} ,
       content  => $self->converted_content ,
       page     => $self->metadata ,
       site     => $self->hid ,
     };
-    $data->{post} = $self if $self->does('HiD::Role::IsPost');
 
-    $data->{page}{url} = $self->url if $self->can( 'url' );
+    foreach my $method ( qw/ categories date tags title url / ) {
+      $data->{page}{$method} = $self->$method
+        if $self->can( $method );
+    }
 
     return $data;
   },
@@ -157,7 +162,7 @@ around BUILDARGS => sub {
   my %args = ( ref $_[0] and ref $_[0] eq 'HASH' ) ? %{ $_[0] } : @_;
 
   unless ( $args{content} and $args{metadata} ) {
-    my $file_content = path( $args{input_filename} )->slurp_utf8;
+    my $file_content = read_file( $args{input_filename}, binmode => ':utf8' );
 
     my( $metadata , $content );
     if ( $file_content =~ /^---/ ) {
@@ -173,7 +178,7 @@ around BUILDARGS => sub {
     }
 
     $args{content}  = $content;
-    $args{metadata} = Load( $metadata ) // {};
+    $args{metadata} = Load( encode('utf8',$metadata) ) // {};
   }
 
   return $class->$orig( \%args );
@@ -212,7 +217,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -280,7 +285,7 @@ Data for passing to template processing function.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -288,7 +293,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
