@@ -2,21 +2,26 @@
 
 
 package HiD::Role::IsPost;
-$HiD::Role::IsPost::VERSION = '1.95_92';
+$HiD::Role::IsPost::VERSION = '1.1';
+BEGIN {
+  $HiD::Role::IsPost::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use DateTime;
 use Date::Parse    qw/ str2time  /;
-
+use File::Basename qw/ fileparse /;
 use HiD::Types;
+use YAML::XS;
 
 
 has author => (
@@ -30,10 +35,10 @@ sub _build_author {
   my $self = shift;
 
   my $author = $self->get_metadata( 'author' );
+
   return $author if defined $author;
 
-  my $default_author = $self->get_config( 'default_author' );
-  return $default_author if defined $default_author;
+  return 'DRAFT AUTHOR -- FIX' if $self->is_draft;
 
   die "Need author for " . $self->basename . "\n"
 }
@@ -91,25 +96,15 @@ has date => (
       ( $year , $month , $day ) = $self->input_filename
         =~ m|^.*?/([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})-|;
       return DateTime->new(
-        year      => $year ,
-        month     => $month ,
-        day       => $day ,
-        time_zone => 'UTC' ,
+        year  => $year ,
+        month => $month ,
+        day   => $day
       );
     }
   },
 );
 
 
-has description => (
-  is      => 'ro' ,
-  isa     => 'Maybe[Str]' ,
-  lazy    => 1 ,
-  builder => '_build_description' ,
-);
-sub _build_description { shift->get_metadata( 'description' ) }
-
-
 has excerpt => (
   is      => 'ro',
   isa     => 'Str',
@@ -137,8 +132,6 @@ sub _build_excerpt {
 has tags => (
   is      => 'ro' ,
   isa     => 'ArrayRef',
-  traits  => [ qw/ Array / ] ,
-  handles => { join_tags => 'join' } ,
   default => sub {
     my $self = shift;
 
@@ -212,9 +205,6 @@ around BUILDARGS => sub {
 };
 
 
-sub all_tags { shift->join_tags(',') }
-
-
 my $drafts_dir;
 sub is_draft {
   my $self = shift;
@@ -231,7 +221,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -262,10 +252,6 @@ post-specific attributes and methods.
 
 DateTime object for this post.
 
-=head2 description
-
-A one-line synopsis of the post (used, e.g., for metadata information used by Open Graph)
-
 =head2 excerpt
 
 It is generally useful to summarize or lead a post with a "read more" tag
@@ -280,10 +266,6 @@ want to list the full post on the front page.
 
 =head1 METHODS
 
-=head2 all_tags
-
-Returns all tags for this post, joined together with commas
-
 =head2 is_draft
 
 Returns a boolean value indicating whether this post is coming from the drafts
@@ -291,7 +273,7 @@ folder or not.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -299,7 +281,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
