@@ -2,20 +2,24 @@
 
 
 package HiD::Role::IsPublished;
-$HiD::Role::IsPublished::VERSION = '1.95_92';
+$HiD::Role::IsPublished::VERSION = '1.1';
+BEGIN {
+  $HiD::Role::IsPublished::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose::Role;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Path::Tiny;
-
+use File::Basename  qw/ fileparse /;
 use HiD::Types;
+use Path::Class     qw/ file /;
 
 requires 'publish';
 
@@ -30,7 +34,7 @@ has basename => (
 sub _build_basename {
   my $self = shift;
   my $ext = '.' . $self->ext;
-  return path( $self->input_filename )->basename( $ext );
+  return fileparse( $self->input_filename , $ext );
 }
 
 
@@ -44,8 +48,11 @@ has baseurl => (
 sub _build_baseurl {
   my $self = shift;
 
-  my $base_url = $self->get_config('baseurl');
-  return defined $base_url ? $base_url : '/';
+  my $base_url = $self->config->{baseurl};
+  if( defined $base_url ) {
+    return $base_url;
+  }
+  return '/';
 }
 
 
@@ -79,7 +86,11 @@ has input_path => (
   is      => 'ro' ,
   isa     => 'HiD_DirPath' ,
   lazy    => 1 ,
-  default => sub { path( shift->input_filename )->parent->stringify() },
+  default => sub {
+    my $self = shift;
+    my( undef , $path ) = fileparse( $self->input_filename );
+    return $path;
+  },
 );
 
 
@@ -93,7 +104,7 @@ has output_filename => (
     my $url = $self->url;
     $url .= 'index.html' if $url =~ m|/$|;
 
-    return path( $self->dest_dir , $url )->stringify;
+    return file( $self->dest_dir , $url )->stringify;
   },
 );
 
@@ -119,7 +130,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -181,7 +192,7 @@ The URL to the output path for the written file.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -189,7 +200,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
