@@ -2,14 +2,20 @@
 
 
 package HiD::Types;
-$HiD::Types::VERSION = '1.95_92';
-use 5.014; # strict, unicode_strings
+$HiD::Types::VERSION = '1.1';
+BEGIN {
+  $HiD::Types::AUTHORITY = 'cpan:GENEHACK';
+}
+
+use 5.014;
 use utf8;
+use strict;
 use autodie;
 use warnings;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
 use Moose::Util::TypeConstraints;
 
@@ -53,7 +59,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -65,7 +71,7 @@ Type constraints for HiD.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -73,7 +79,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
