@@ -2,29 +2,35 @@
 
 
 package HiD::VirtualPage;
-$HiD::VirtualPage::VERSION = '1.95_92';
+$HiD::VirtualPage::VERSION = '1.1';
+BEGIN {
+  $HiD::VirtualPage::AUTHORITY = 'cpan:GENEHACK';
+}
 use Moose;
 use namespace::autoclean;
 
-use 5.014; # strict, unicode_strings
+use 5.014;
 use utf8;
 use autodie;
 use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
+use feature     qw/ unicode_strings /;
 
-use Path::Tiny;
+use File::Basename  qw/ fileparse /;
+use File::Path      qw/ make_path /;
+use Path::Class     qw/ file / ;
 
 
 has output_filename => (
-  is       => 'ro' ,
-  isa      => 'Str' ,
+  is => 'ro' ,
+  isa => 'Str' ,
   required => 1 ,
 );
 
 has content => (
-  is       => 'ro' ,
-  isa      => 'Str' ,
+  is => 'ro' ,
+  isa => 'Str' ,
   required => 1 ,
 );
 
@@ -32,12 +38,13 @@ has content => (
 sub publish {
   my $self = shift;
 
-  my $out = path( $self->output_filename );
-  my $dir = $out->parent;
+  my( undef , $dir ) = fileparse( $self->output_filename );
 
-  $dir->mkpath() unless $dir->is_dir;
+  make_path $dir unless -d $dir;
 
-  $out->spew_utf8( $self->content );
+  open( my $out , '>:utf8' , $self->output_filename ) or die $!;
+  print $out $self->content;
+  close( $out );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -47,7 +54,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -80,7 +87,7 @@ Publish -- write out to disk -- this data from this object.
 
 =head1 VERSION
 
-version 1.95_92
+version 1.1
 
 =head1 AUTHOR
 
@@ -88,7 +95,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by John SJ Anderson.
+This software is copyright (c) 2012 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
